/*
 * @Description: 物料规则相关
 * @Author: Ben Lin
 * @version:
 * @Date: 2024-06-19 20:34:27
 * @LastEditors: Ben Lin
 * @LastEditTime: 2024-09-11 19:33:59
 */

import { Ref, h, unref } from 'vue';
import { DeleteEntity, GetEnum, getEntity } from '/@/api/tigerapi/system';
import { ActionItem, BasicColumn, FormSchema, useTable } from '/@/components/Table';
import { isNullOrEmpty, isNullOrUnDef } from '/@/utils/is';
import { Tag } from 'ant-design-vue';
import { useLocale } from '/@/locales/useLocale';
import { useDrawer } from '/@/components/Drawer';
import { EditOperation, Search, custDel } from '../data';
import { SaveBasItemRule } from '/@/api/tigerapi/mes/baserule';

const { getLocale } = useLocale();
function _default() {
  const ActionColumn: BasicColumn = {
    width: 80,
    title: '操作',
    dataIndex: 'action',
    slots: { customRender: 'action' },
    fixed: undefined,
  };
  
  /**
   * @description: 些自定义方法
   * @return {*}
   */
  const methods = {
    /**
     * @description: 获取新增按钮的行为
     * @return {*}
     */
    CreateAction: (type: string) => {
      return {
        action: 'drawer', //drawer(打开左侧抽屉框) | go(跳转到新的页面)
      };
    },
    /**
     * @description: 操作字段自定义按钮
     * @return {*}
     */
    ActionItem: (params: Recordable<any>, data, ...args): ActionItem[] => {
      if (!isNullOrUnDef(data[1])) {
        data[1].popConfirm.confirm = custDel.bind(null, args, params);
      }
      return data;
    },
    /**
     * @description: 高级表单和详情页面返回主页面的url
     * @return {*}
     */
    GetHomeUrl: () => {
      return `/MaterialInfo`;
    },
    GetBaseColumns: (type: string) => {
      return baseColumns[type];
    },
    GetSearchForm: (type: string) => {
      return searchForms[type];
    },
    GetCrudForm: (type: string) => {
      return crudForms[type];
    },
    GetBaseForm: () => {
      return [
        {
          field: 'ITEM_CODE',
          label: '物料编码',
          component: 'Input',
          required: true,
          colProps: {
            span: 8,
          },
          dynamicDisabled: ({ values }) => {
            return true;
          },
        },
        {
          label: '物料名称',
          field: 'ITEM_NAME',
          required: true,
          component: 'Input',
          colProps: {
            span: 8,
          },
          dynamicDisabled: ({ values }) => {
            return true;
          },
        },
        {
          label: 'ID',
          field: 'ID',
          component: 'Input',
          colProps: {
            span: 8,
          },
          show: false,
        },
      ];
    },
    /**
     * @description: 获取卡片内配置列表，以循环显示多个卡片并配置多个插槽
     * @return {*}
     */    
    GetBaseCards: (type: string) => {
      return [
        {
          name: 'BaseForm',
          slots: [],
          preIcons: {},
          title: '物料信息',
          entityName: 'BAS_ITEM',
        },
        // {
        //   name: 'prodinfo',
        //   slots: ['addRot', 'setRot'],
        //   preIcons: { addRot: 'search|svg', setRot: 'config|svg' },
        //   title: '产品信息',
        // },
        // { name: 'rotinfo', slots: ['add'], preIcons: { add: 'search|svg' }, title: '工艺信息' },
      ];
    },
    /**
     * @description: 获取右侧边框use方法
     * @return {*}
     */    
    GetUseDrawers: () => {
      return [{
        'BAS_ITEM_CUST': useDrawer(),
      }];
    },
    /**
     * @description: 获取表格use列表
     * @param {string} type
     * @param {array} args
     * @return {*}
     */    
    GetUseTables: (data: Ref<{}>, ...args) => {
      return {
        BAS_ITEM_CUST: useTable({
          title: '列表信息',
          dataSource: data.value['BAS_ITEM_CUST'],
          columns: baseColumns['BAS_ITEM_CUST'],
          formConfig: {
            labelWidth: 140,
            schemas: searchForms['BAS_ITEM_CUST'],
            submitFunc: () => Search('BAS_ITEM_CUST', data, args[0]), //自定义查询提交按钮的方法，触发查询提交事件
          },
          useSearchForm: true,
          showTableSetting: false,
          bordered: true,
          canResize: true,
          showIndexColumn: false,
          actionColumn: {
            width: 130,
            title: '操作',
            dataIndex: 'action',
            slots: { customRender: 'action' },
            fixed: 'right',
          }, //自定义操作列
        })
      };
    },
    /**
     * @description: 表格查询回调，父组件中通过子组件触发的事件获取传入的值，做具体的查询逻辑实现
     * @param {*} d
     * @return {*}
     */
    FormSearch: (d) => {
      let data = {} as any;
      switch (d.type) {
        case 'BAS_ITEM_CUST':
          data = d.data.value[d.type].filter(
            (item) =>
              item.RULE_CODE.includes(d.values.RULE_CODE),
          );
          if (isNullOrEmpty(d.values.RULE_CODE)) {
            data = d.data.value[d.type];
          }
          break;
      }
      return data;
    },
    KeyFieldValues: (val: string, id: string) => {
      return { ITEM_CODE: val, ITEM_ID: id };
    } /**
     * @description: 自定义明细表中编辑返回方法
     * @param {string} type
     * @param {*} d
     * @param {*} u
     * @return {*}
     */,
    EditOperation: (data: Ref<any[]>, d, u, item) => {
      //更新
      var _data = data.value[item].map((item) => {
        if (item['ID'] == d.ID)
          return {
            ...item,
            RULE_CODE: d.RULE_CODE,
            CUST_CODE: d.CUST_CODE,
            REMARK: d.REMARK,
          };
        return item;
      });
      EditOperation(data,d, u, item, _data);
    },
    /**
     * @description: 获取标题信息
     * @param {string} type
     * @return {*}
     */
    GetTitle: () => {
      return {
        pageTitle: '物料管理',
        pageContent: '这里可以添加和修改物料规则。',
        tableTitle: {
          BAS_ITEM_CUST: '物料规则管理',
        }
      };
    },
    GetUseForm: () => {
      return {};
    },
    /**
     * @description: 提交所有
     * @return {*}
     */
    SubmitAll: (data: Ref<any[]>, keyFieldValues: Ref<{}>, ...args) => {
      SaveBasItemRule({
        ItemCusts: data.value['BAS_ITEM_CUST'],
      }).then((action) => {
        if (action.IsSuccessed) {
          args[0]();
        }
      });
    },
  };

  /* 以下是内部方法，不export，供上面的方法调用 */

  const baseColumns = {
    BAS_ITEM_CUST: [
      {
        title: '物料编码',
        dataIndex: 'ITEM_CODE',
        // ifShow: false,
        width: 180,
      },
      {
        title: '物料名称',
        dataIndex: 'ITEM_NAME',
      },
      {
        title: '规则编码',
        dataIndex: 'RULE_CODE',
      },
      {
        title: '备注',
        dataIndex: 'REMARK',
      },
      {
        title: '更新时间',
        dataIndex: 'UPDATE_TIME',
      },
      {
        title: '更新人',
        dataIndex: 'UPDATE_USER',
      },
    ]
  }

  const searchForms = {
    BAS_ITEM_CUST: [
      {
        field: 'RULE_CODE',
        label: '规则编码',
        component: 'Input',
        colProps: {
          span: 8,
        },
      },
      // {
      //   label: '物料名称',
      //   field: 'ITEM_NAME',
      //   component: 'Input',
      //   colProps: {
      //     span: 8,
      //   },
      // },
    ] as FormSchema[],
  }

  const crudForms = {
    BAS_ITEM_CUST: [
      {
        field: 'ITEM_CODE',
        label: '物料编码',
        component: 'Input',
        required: true,
        colProps: {
          span: 24,
        },
        dynamicDisabled: ({ values }) => {
          return true;
        },
      },
      {
        label: '客户编码',
        field: 'CUST_CODE',
        component: 'Input',
        colProps: {
          span: 22,
        },
      },
      {
        field: 'BAS_CUSTOMER1PSelect_0', //按低代码配置的规则，实体名+序号+PSelect_0，序号用来区分多个的时候，PSelect_0这是个固定后缀
        label: '1',
        defaultValue: 'BAS_CUSTOMER',
        component: 'Input',
        colProps: { span: 2 },
        colSlot: 'BAS_CUSTOMER1add', //按低代码配置的规则，实体名+序号+add，序号用来区分多个的时候，add这是个固定后缀
      },
      {
        label: '规则编码',
        field: 'RULE_CODE',
        component: 'Input',
        colProps: {
          span: 22,
        },
      },
      {
        field: 'BAS_CODE_RULE1PSelect_0', //按低代码配置的规则，实体名+序号+PSelect_0，序号用来区分多个的时候，PSelect_0这是个固定后缀
        label: '2',
        defaultValue: 'BAS_CODE_RULE',
        component: 'Input',
        colProps: { span: 2 },
        colSlot: 'BAS_CODE_RULE1add', //按低代码配置的规则，实体名+序号+add，序号用来区分多个的时候，add这是个固定后缀
      },
      {
        label: '备注',
        field: 'REMARK',
        component: 'Input',
        colProps: {
          span: 24,
        },
      },
      {
        label: 'ITEM_ID',
        field: 'ITEM_ID',
        component: 'Input',
        colProps: {
          span: 24,
        },
        show: false,
      },
      {
        label: 'ID',
        field: 'ID',
        component: 'Input',
        colProps: {
          span: 24,
        },
        show: false,
      },
    ] as FormSchema[],
  }

  return [methods, ActionColumn];
}

export default _default;
